PerformanceLevel

Enum PerformanceLevel 

pub enum PerformanceLevel {
    Auto,
    Low,
    High,
    Manual,
    ProfileStandard,
    ProfileMinSclk,
    ProfileMinMclk,
    ProfilePeak,
    PerfDeterminism,
    ProfileExit,
}
Variants



Auto

When auto is selected, the driver will attempt to dynamically select the optimal power profile for current conditions in the driver.



Low

When low is selected, the clocks are forced to the lowest power state.



High

When high is selected, the clocks are forced to the highest power state.



Manual

When manual is selected, power states can be manually adjusted via pp_dpm_* files (GpuHandle::set_enabled_power_levels) and pp_od_clk_voltage (GpuHandle::set_clocks_table).



ProfileStandard

Fixed profiling mode with ASIC-specific clocks.



ProfileMinSclk

Profiling mode that forces the core clock to the lowest level.



ProfileMinMclk

Profiling mode that forces the memory clock to the lowest level.



ProfilePeak

Profiling mode that forces clocks to the highest levels.



PerfDeterminism

next two are undocumented, but exist in the kernel’s amd_dpm_forced_level enum https://github.com/torvalds/linux/blob/e1914add2799225a87502051415fc5c32aeb02ae/drivers/gpu/drm/amd/include/kgd_pp_interface.h#L56-L67 Kernel extension for deterministic performance profiling.



ProfileExit

Kernel extension used to exit profiling mode.