pub struct PowerProfileModesTable {
pub modes: BTreeMap<u16, String>,
pub active: u16,
}
Table of predefined power profile modes
https://kernel.org/doc/html/latest/gpu/amdgpu/thermal.html#pp-power-profile-mode
The currently active mode
Parse the table from a given string
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.