Struct amdgpu_sysfs::hw_mon::HwMon

source ·
pub struct HwMon { /* private fields */ }
Reprepesents a hardware monitor. Hardware monitors are used to report real-time information about the device, such as temperatures and power usage.

Implementations

Most of the time you may want to access HwMons through the GpuHandle they’re bound to.

Returns a HashMap of temperatures(in degress celsius), indexed by the labels (example: “edge”).

Gets the current GFX/compute clockspeed in MHz.

Gets the current memory clockspeed in MHz.

Gets the average power (currently) used by the GPU in watts.

Gets the current power cap of the GPU in watts.

Sets the current power cap of the GPU in watts.

Gets the maximum possible power cap for the GPU in watts. If overclocking is disabled, this is probably the same as the default cap.

Gets the minimum possible power cap for the GPU in watts.

Gets the default power cap for the GPU in watts.

Gets the pulse width modulation fan level.

Sets the pulse width modulation fan level.

Gets the current fan speed in RPM.

Gets the maximum possible fan speed in RPM.

Gets the minimum possible fan speed in RPM.

Gets the currently desired fan speed in RPM.

Sets the desired fan speed in RPM.

Gets the pulse width modulation control method.

Sets the fan control method (pwm1_enable).

Gets the GPU voltage in millivolts.

Gets the north bridge voltage in millivolts.