pub enum PerformanceLevel {
    Auto,
    Low,
    High,
    Manual,
}
Variants



Auto

When auto is selected, the driver will attempt to dynamically select the optimal power profile for current conditions in the driver.



Low

When low is selected, the clocks are forced to the lowest power state.



High

When high is selected, the clocks are forced to the highest power state.



Manual

When manual is selected, power states can be manually adjusted via pp_dpm_* files (GpuHandle::set_enabled_power_levels) and pp_od_clk_voltage (GpuHandle::set_clocks_table).