Struct amdgpu_sysfs::gpu_handle::overdrive::vega20::Table
source · pub struct Table {
pub current_sclk_range: Range,
pub current_mclk_range: Range,
pub vddc_curve: Vec<ClocksLevel>,
pub voltage_offset: Option<i32>,
pub od_range: OdRange,
}Expand description
Vega20 clocks table.
Fields
current_sclk_range: RangeThe current core clock range.
current_mclk_range: RangeThe current memory clock range.
vddc_curve: Vec<ClocksLevel>The current voltage curve. May be empty if the GPU does not support it.
voltage_offset: Option<i32>Voltage offset(in mV) applied on target voltage calculation. This is available for Sienna Cichlid, Navy Flounder and Dimgrey Cavefish.
od_range: OdRangeThe allowed ranges for clockspeeds and voltages.
Implementations
sourceimpl Table
impl Table
sourcepub fn clear(&mut self)
pub fn clear(&mut self)
Clears the table of all “applicable” values.
This removes all values except the allowed range.
You can use it to avoid overwriting the table with already present values, as it can be problematic on some cards.
It is intended to be used before calling set_* functions and generating commands/writing the table.