Trait amdgpu_sysfs::sysfs::SysFS

source ·
pub trait SysFS {
    fn get_path(&self) -> &Path;

    fn read_file(&self, file: &str) -> Result<String, Error> { ... }
    fn read_file_parsed<T: FromStr<Err = E>, E: ToString>(
        &self,
        file: &str
    ) -> Result<T, Error> { ... } fn write_file<C: AsRef<[u8]> + Send>(
        &self,
        file: &str,
        contents: C
    ) -> Result<(), Error> { ... } }
General functionality of a SysFS.

Required Methods

Gets the path of the current SysFS.

Provided Methods

Reads the content of a file in the SysFS.

Reads the content of a file and then parses it

Write to a file in the SysFS.

Implementors